@@ -20,7 +20,6 @@ package jcifs.netbios;
 
 import java.net.*;
 import java.io.IOException;
-import java.io.InterruptedIOException;
 import java.util.HashMap;
 import java.util.StringTokenizer;
 import jcifs.Config;
@@ -145,8 +144,6 @@ class NameServiceClient implements Runnable {
         // be ignored; see tryClose comment.
         if( socket == null ) {
             socket = new DatagramSocket( lport, laddr );
-jcifs.Config.socketCount++;
-log.println(jcifs.Config.socketCount + ": new Socket: " + socket);
             thread = new Thread( this, "JCIFS-NameServiceClient" );
             thread.setDaemon( true );
             thread.start();
@@ -164,10 +161,7 @@ log.println(jcifs.Config.socketCount + ": new Socket: " + socket);
              */
 
             if( socket != null ) {
-String s = socket.toString();
                 socket.close();
-jcifs.Config.socketCount--;
-log.println(jcifs.Config.socketCount + ": socket closed: " + s);
                 socket = null;
             }
             thread = null;
@@ -259,6 +253,7 @@ log.println(jcifs.Config.socketCount + ": socket closed: " + s);
                     }
 
                 } catch( InterruptedException ie ) {
+                    throw new IOException(ie.getMessage());
                 } finally {
                     responseTable.remove( nid );
                 }
