@@ -186,6 +186,15 @@ public final class NbtAddress {
             try {
                 localInetAddress = InetAddress.getLocalHost();
             } catch( UnknownHostException uhe ) {
+                /* Java cannot determine the localhost. This is basically a config
+                 * issue on the host. There's not much we can do about it. Just
+                 * to suppress NPEs that would result we can create a possibly bogus
+                 * address. Pretty sure the below cannot actually thrown a UHE tho.
+                 */
+                try {
+                    localInetAddress = InetAddress.getByName("127.0.0.1");
+                } catch( UnknownHostException ignored ) {
+                }
             }
         }
 
