@@ -145,6 +145,33 @@ public class SID extends rpc.sid_t {
         }
     }
 
+    static public void resolveSids(String authorityServerName,
+                NtlmPasswordAuthentication auth,
+                SID[] sids,
+                int offset,
+                int length) throws IOException {
+        ArrayList list = new ArrayList(sids.length);
+        int si;
+
+        for (si = 0; si < length; si++) {
+            SID sid = (SID)sid_cache.get(sids[offset + si]);
+            if (sid != null) {
+                sids[offset + si].type = sid.type;
+                sids[offset + si].domainName = sid.domainName;
+                sids[offset + si].acctName = sid.acctName;
+            } else {
+                list.add(sids[offset + si]);
+            }
+        }
+
+        if (list.size() > 0) {
+            sids = (SID[])list.toArray(new SID[0]);
+            SID.resolveSids0(authorityServerName, auth, sids);
+            for (si = 0; si < sids.length; si++) {
+                sid_cache.put(sids[si], sids[si]);
+            }
+        }
+    }
     /**
      * Resolve an array of SIDs using a cache and at most one MSRPC request.
      * <p>
@@ -187,13 +214,14 @@ public class SID extends rpc.sid_t {
         DcerpcHandle handle = null;
         LsaPolicyHandle policyHandle = null;
         lsarpc.LsarDomainInfo info = new lsarpc.LsarDomainInfo();
-        MsrpcQueryInformationPolicy2 rpc;
+        MsrpcQueryInformationPolicy rpc;
 
         try {
             handle = DcerpcHandle.getHandle("ncacn_np:" + server +
                     "[\\PIPE\\lsarpc]", auth);
-            policyHandle = new LsaPolicyHandle(handle, null, 0x02000000);
-            rpc = new MsrpcQueryInformationPolicy2(policyHandle,
+            // NetApp doesn't like the 'generic' access mask values
+            policyHandle = new LsaPolicyHandle(handle, null, 0x00000001);
+            rpc = new MsrpcQueryInformationPolicy(policyHandle,
                         (short)lsarpc.POLICY_INFO_ACCOUNT_DOMAIN,
                         info);
             handle.sendrecv(rpc);
@@ -231,7 +259,7 @@ public class SID extends rpc.sid_t {
         System.arraycopy(src, si, identifier_authority, 0, 6);
         si += 6;
         if (sub_authority_count > 100)
-            throw new RuntimeException( "Invalid SID" );
+            throw new RuntimeException( "Invalid SID sub_authority_count" );
         sub_authority = new int[sub_authority_count];
         for (int i = 0; i < sub_authority_count; i++) {
             sub_authority[i] = ServerMessageBlock.readInt4( src, si );
