@@ -182,8 +182,6 @@ public class SmbTransport extends Transport implements SmbConstants {
             } else {
                 socket = new Socket( address.getHostAddress(), 139, localAddr, localPort );
             }
-jcifs.Config.socketCount++;
-log.println(jcifs.Config.socketCount + ": new Socket: " + socket);
             socket.setSoTimeout( SO_TIMEOUT );
             out = socket.getOutputStream();
             in = socket.getInputStream();
@@ -193,13 +191,8 @@ log.println(jcifs.Config.socketCount + ": new Socket: " + socket);
             out.write( sbuf, 0, ssp.writeWireFormat( sbuf, 0 ));
             if (readn( in, sbuf, 0, 4 ) < 4) {
                 try {
-String s = socket.toString();
                     socket.close();
-jcifs.Config.socketCount--;
-log.println(jcifs.Config.socketCount + ": socket closed: " + s);
                 } catch(IOException ioe) {
-log.println(jcifs.Config.socketCount + ": socket close exception:");
-ioe.printStackTrace(log);
                 }
                 throw new SmbException( "EOF during NetBIOS session request" );
             }
@@ -213,10 +206,7 @@ ioe.printStackTrace(log);
                     switch (errorCode) {
                         case NbtException.CALLED_NOT_PRESENT:
                         case NbtException.NOT_LISTENING_CALLED:
-String s = socket.toString();
                             socket.close();
-jcifs.Config.socketCount--;
-log.println(jcifs.Config.socketCount + ": socket closed: " + s);
                             break;
                         default:
                             disconnect( true );
@@ -259,8 +249,6 @@ log.println(jcifs.Config.socketCount + ": socket closed: " + s);
                 } else {
                     socket = new Socket( address.getHostAddress(), port, localAddr, localPort );
                 }
-jcifs.Config.socketCount++;
-log.println(jcifs.Config.socketCount + ": new Socket: " + socket);
                 socket.setSoTimeout( SO_TIMEOUT );
                 out = socket.getOutputStream();
                 in = socket.getInputStream();
@@ -361,10 +349,7 @@ log.println(jcifs.Config.socketCount + ": new Socket: " + socket);
         socket.shutdownOutput();
         out.close();
         in.close();
-String s = socket.toString();
         socket.close();
-jcifs.Config.socketCount--;
-log.println(jcifs.Config.socketCount + ": socket closed: " + s);
         digest = null;
     }
 
@@ -635,6 +620,8 @@ log.println(jcifs.Config.socketCount + ": socket closed: " + s);
             }
         } catch( SmbException se ) {
             throw se;
+        } catch( InterruptedException ie ) {
+            throw new SmbException( ie.getMessage(), ie );
         } catch( IOException ioe ) {
             throw new SmbException( ioe.getMessage(), ioe );
         }
