@@ -29,11 +29,11 @@ class SmbTree {
     private static int tree_conn_counter;
 
     private int tid;
-    private String share;
 
+    String share;
     String service = "?????";
     SmbSession session;
-    boolean treeConnected, inDfs;
+    boolean treeConnected, inDfs, inDomainDfs;
     int tree_num;
 
     SmbTree( SmbSession session, String share, String service ) {
@@ -163,7 +163,7 @@ synchronized(transport) {
     }
     void treeDisconnect( boolean inError ) {
 synchronized( session.transport ) {
-        if (treeConnected && !inError) {
+        if (treeConnected && !inError && tid != 0) {
             try {
                 send( new SmbComTreeDisconnect(), null );
             } catch( SmbException se ) {
@@ -173,6 +173,8 @@ synchronized( session.transport ) {
             }
         }
         treeConnected = false;
+        inDfs = false;
+        inDomainDfs = false;
 }
     }
 
@@ -181,6 +183,7 @@ synchronized( session.transport ) {
             ",service=" + service +
             ",tid=" + tid +
             ",inDfs=" + inDfs +
+            ",inDomainDfs=" + inDomainDfs +
             ",treeConnected=" + treeConnected + "]";
     }
 }
